@@ -5,9 +5,9 @@ import io
 from datetime import datetime
 import time
 from pathlib import Path
-
+import os
 from src.comm.docker_ver import *
-path_home = '/localpath/' if docker_ver() else str(Path.home())
+path_home = os.getenv('LCP_DKR')+'/' if docker_ver() else str(Path.home())
 
 class Initializer(object):
 	"""docstring for Initializer"""
@@ -19,10 +19,7 @@ class Initializer(object):
 		
 		# prefixes
 		if self.storage.type == 'local':
-			if not docker_ver():
-				surrogate_dataset = self.storage.dataset.replace(path_home, 'localpath')
-			else:
-				surrogate_dataset = self.storage.dataset
+			surrogate_dataset = self.storage.dataset
 
 			self.prefix_meta = path_home + '/.stack/' +  surrogate_dataset
 			self.prefix_curr = path_home + '/.stack/' +  surrogate_dataset + 'current/'
@@ -131,7 +128,7 @@ class Initializer(object):
 		# stores the diffs of the first commit
 		for file in self.dataset:
 			# TODO: let's name the diffs with just numbering for now
-			diff = self.prefix_diffs + file['key'].replace(self.storage.prefix_ignore,'') + '/' + str(1).zfill(10)
+			diff = self.prefix_diffs + file['key'] + '/' + str(1).zfill(10)
 			self.storage.copyFileGlobal(file['key'],diff)		
 		return True
 
@@ -147,15 +144,9 @@ class Initializer(object):
 		commits = []
 		for file in self.dataset:
 			
-			if self.storage.type == 'local':
-				if docker_ver():
-					prefix_commit = '.stack' + self.storage.dataset + 'commits/'
-				else:
-					prefix_commit = self.prefix_commit.replace(path_home,'')
-			else:
-				prefix_commit = self.prefix_commit
+			prefix_commit = self.prefix_commit
 
-			commitpath = prefix_commit + file['key'].replace(self.storage.prefix_ignore,'') + '/' + str(1).zfill(10)
+			commitpath = prefix_commit + file['key'] + '/' + str(1).zfill(10)
 			commits.append(commitpath)
 
 		time = datetime.now().strftime("%d/%m/%Y %H:%M:%S")
@@ -191,7 +182,7 @@ class Initializer(object):
 		for file in self.dataset:
 			# gets the address of the diff
 			# TODO: let's name the diffs with just numbering for now
-			diff = self.prefix_diffs + file['key'].replace(self.storage.prefix_ignore,'') + '/' + str(1).zfill(10)
+			diff = self.prefix_diffs + file['key'] + '/' + str(1).zfill(10)
 
 			commit = {
 				'key'	: file['key'],
@@ -205,12 +196,12 @@ class Initializer(object):
 
 			history = {}
 			history[1] = commit
-			commitpath = self.prefix_commit + file['key'].replace(self.storage.prefix_ignore,'') + '/' + str(1).zfill(10)
+			commitpath = self.prefix_commit + file['key'] + '/' + str(1).zfill(10)
 			self.storage.addFileFromBinaryGlobal(commitpath,io.BytesIO(json.dumps(commit).encode('ascii')))
 			
 			self.storage.resetBuffer()
 			
-			histpath = self.prefix_history + file['key'].replace(self.storage.prefix_ignore,'') + '/history.json'
+			histpath = self.prefix_history + file['key'] + '/history.json'
 			self.storage.addFileFromBinaryGlobal(histpath,io.BytesIO(json.dumps(history).encode('ascii')))
 			self.storage.resetBuffer()
 
@@ -220,11 +211,10 @@ class Initializer(object):
 
 	def getLatestDiffNumber(self, key):
 		# checks all the diffs
-		diff_path, _ = self.storage.loadListInPath(self.prefix_diffs + key.replace(self.storage.prefix_ignore,'') + '/')
+		diff_path, _ = self.storage.loadListInPath(self.prefix_diffs + key + '/')
 		
 		# gets the list in number
-		print(diff_path)
-		diff_path = [int(x.replace(self.prefix_diffs + key.replace(self.storage.prefix_ignore,'') + '/','')) for x in diff_path]
+		diff_path = [int(x.replace(self.prefix_diffs + key + '/','')) for x in diff_path]
 		
 		if len(diff_path):
 			return max(diff_path)
