@@ -36,8 +36,7 @@ def connect_cli(uri: str):
     
     try:
         if docker_ver():
-            if uri[0] == '.':
-                uri = uri[1:]
+            assert(False)
 
         api.init(uri)
         api.connect_post_cli()
@@ -85,7 +84,6 @@ def remove_command(file: str, target_subpath: str=''):
     remove(api.Initializer,[file],target_subpath)
     api.commit('', cmd=False)
 
-
 @app.command("disconnect")
 def disconnect_cli(uri: str):
     '''
@@ -137,10 +135,10 @@ def status_api():
     '''
         Prints the status of the dataset
     '''
-    # try:
-    printStatus(api.Initializer)
-    # except:
-    #     return Exception
+    try:
+        printStatus(api.Initializer)
+    except:
+        return Exception
 
 @app.command("sync")
 def sync_api(comment: str=''):
@@ -180,6 +178,5 @@ def revert_api(version):
     api.commit('', cmd=False)
     return True
 
-
 if __name__ == "__main__":
     app()
